@@ -32,9 +32,8 @@ define([
             , VP_CLASS_STYLE_FLEX_ROW_CENTER    
             , VP_CLASS_STYLE_FLEX_ROW_BETWEEN
 
-            , VP_CLASS_STYLE_WIDTH_10PERCENT
-            , VP_CLASS_STYLE_WIDTH_15PERCENT
-            , VP_CLASS_STYLE_WIDTH_20PERCENT
+            , VP_CLASS_STYLE_WIDTH_25PERCENT
+            , VP_CLASS_STYLE_WIDTH_35PERCENT
             , VP_CLASS_STYLE_WIDTH_100PERCENT
 
             , VP_CLASS_STYLE_BGCOLOR_C4C4C4
@@ -45,8 +44,6 @@ define([
             , VP_ID_APIBLOCK_OPTION_WHILE_ARG_2
             , VP_ID_APIBLOCK_OPTION_WHILE_ARG_3
             , VP_ID_APIBLOCK_OPTION_WHILE_ARG_4
-            , VP_ID_APIBLOCK_OPTION_WHILE_ARG_5
-            , VP_ID_APIBLOCK_OPTION_WHILE_ARG_6
             , VP_ID_APIBLOCK_OPTION_WHILE_PLUS
             , VP_ID_APIBLOCK_OPTION_WHILE_DELETE
 
@@ -56,7 +53,6 @@ define([
             , WHILE_BLOCK_SELECT_VALUE_ARG_TYPE
             , WHILE_OPERATOR_ARG2
             , COMPARISON_OPERATOR_IF_ARG4
-            , COMPARISON_OPERATOR_IF_ARG6
 
             , STATE_whileConditionList
 
@@ -65,6 +61,7 @@ define([
     const { MakeOptionContainer
             , MakeOptionDeleteButton
             , MakeOptionPlusButton
+            , MakeOptionSelectBox
             , MakeVpSuggestInputText_apiblock } = baseComponent;
 
     var InitWhileBlockOption = function(thisBlock, optionPageSelector) {
@@ -107,41 +104,11 @@ define([
                     event.stopPropagation();
                 });
 
-                /**
-                  * @event_function
-                  * iF arg4 선택 변경 
-                 */
-                $(document).off(STR_CHANGE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_4 + index + uuid);
-                $(document).on(STR_CHANGE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_4 + index + uuid, function(event) {
-                   
-                    var ifConditionListState = thisBlock.getState(STATE_whileConditionList);
-                    var ifConditionState = ifConditionListState[index];
-                    var selectedValue = $(STR_COLON_SELECTED, this).val();
-                    if (selectedValue == 'none') {
-                        selectedValue = STR_EMPTY;
-                    }
 
-                    var updatedValue = {
-                        ...ifConditionState
-                        ,arg4: selectedValue
-                    }
-                    
-                    ifConditionListState = UpdateOneArrayValueAndGet(ifConditionListState, index, updatedValue);
-                    thisBlock.setState({
-                        [STATE_whileConditionList]: ifConditionListState
-                    });
-
-                    var whileBlockCode = GenerateWhileCode(thisBlock);
-                    thisBlock.writeCode(whileBlockCode);
-                    blockContainerThis.renderBlockOptionTab();
-                    event.stopPropagation();
-                });
-
-
-                        for (var k = 1; k < 7; k++) {
+                        for (var k = 1; k < 5; k++) {
                             ((i) => {
             
-                                /** arg1 arg2 arg3 arg4 arg5 arg6 */
+                                /** arg1 arg2 arg3 arg4 */
                                 /** If arg input 입력 변경 이벤트 함수 바인딩 */
                                     $(document).off(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG +i+ index + uuid);
                                     $(document).on(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG +i+ index + uuid, function(event) {
@@ -166,30 +133,10 @@ define([
                                                 ...ifConditionState
                                                 , arg3: inputValue 
                                             }
-                                        }  else if (i == 4) {
-                                            
-                                            updatedValue = {
-                                                ...ifConditionState
-                                                ,arg4: inputValue
-                                            }
-                                            if (inputValue == '') {
-                                                $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_4 + index + uuid).addClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
-                                                $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_5 + index + uuid).addClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
-                                                $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_5 + index + uuid).attr("disabled", true);
-                                            } else {
-                                                $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_4 + index + uuid).removeClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
-                                                $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_5 + index + uuid).removeClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
-                                                $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_5 + index + uuid).attr("disabled", false);
-                                            }
-                                        } else if (i == 5) {
-                                            updatedValue = {
-                                                ...ifConditionState
-                                                , arg5: inputValue 
-                                            }
                                         } else {
                                             updatedValue = {
                                                 ...ifConditionState
-                                                , arg6: inputValue
+                                                , arg4: inputValue
                                             }
                                         }
             
@@ -228,7 +175,7 @@ define([
                     }); 
                 });
                 
-                /** 생성 if condition - arg1, arg2, arg3, arg4, arg5, arg6*/
+                /** 생성 if condition - arg1, arg2, arg3, arg4 */
                 $(document).off(STR_CLICK, vpCommon.wrapSelector(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_PLUS + uuid));
                 $(document).on(STR_CLICK, vpCommon.wrapSelector(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_PLUS + uuid), function(event) {
         
@@ -238,9 +185,7 @@ define([
                         arg1: ''
                         , arg2: ''
                         , arg3: ''
-                        , arg4: ''
-                        , arg5: ''
-                        , arg6: ''
+                        , arg4: 'and'
                     }
                     ifConditionListState = CreateOneArrayValueAndGet(ifConditionListState, ifConditionListState.length, newCondition);
                     thisBlock.setState({
@@ -254,7 +199,7 @@ define([
                 });
     
         
-                /** arg1, arg2, arg3, arg4, arg5, arg6 select 변경 if condition */
+                /** arg1, arg2, arg3, arg4 select 변경 if condition */
                 var bindSelectValueEventFunc_while = function(selectedValue, index, type) {
                     var ifConditionListState = thisBlock.getState(STATE_whileConditionList);
                     var ifConditionState = ifConditionListState[index];
@@ -279,35 +224,10 @@ define([
                             ...ifConditionState
                             , arg3: selectedValue 
                         }
-                     
-                    } else if (type == WHILE_BLOCK_SELECT_VALUE_ARG_TYPE.ARG4) {
-               
-                        if (selectedValue == 'none') {
-                            selectedValue = STR_EMPTY;
-                        }
-                        updatedValue = {
-                            ...ifConditionState
-                            , arg4: selectedValue 
-                        }
-                        if (selectedValue == STR_EMPTY) {
-                            $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_4 + index + uuid).addClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
-                            $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_5 + index + uuid).addClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
-                            $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_5 + index + uuid).attr(STR_DISABLED, true);
-                        } else {
-                            $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_4 + index + uuid).removeClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
-                            $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_5 + index + uuid).removeClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
-                            $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_5 + index + uuid).attr(STR_DISABLED, false);
-                        }
-        
-                    } else if (type == WHILE_BLOCK_SELECT_VALUE_ARG_TYPE.ARG5) {
-                        updatedValue = {
-                            ...ifConditionState
-                            , arg5: selectedValue 
-                        }
                     } else {
                         updatedValue = {
                             ...ifConditionState
-                            , arg6: selectedValue 
+                            , arg4: selectedValue 
                         }
                       
                     }
@@ -339,17 +259,17 @@ define([
         
                         var sbConditionLeft = new sb.StringBuilder();
                         sbConditionLeft.appendFormatLine("<div class='{0}'  ", VP_CLASS_STYLE_FLEX_ROW_BETWEEN);
-                        sbConditionLeft.appendFormatLine("     style='{0}'  >",'width:80%;');
+                        sbConditionLeft.appendFormatLine("     style='{0}'  >",'width:70%;');
                
-                        const { arg1, arg2, arg3, arg4, arg5, arg6 } = condition; 
+                        const { arg1, arg2, arg3, arg4 } = condition; 
                         var loadedVariableNameList_arg1 = [ `'i${index + 1}'`, ...loadedVariableNameList];
                         var loadedVariableNameList_arg3 = [ `'j${index + 1}'`, ...loadedVariableNameList];
-                        var loadedVariableNameList_arg5 = [ `'k${index + 1}'`, ...loadedVariableNameList];
+                        // var loadedVariableNameList_arg5 = [ `'k${index + 1}'`, ...loadedVariableNameList];
 
                         var suggestInputArg1 =  MakeVpSuggestInputText_apiblock(VP_ID_APIBLOCK_OPTION_WHILE_ARG_1 + index + uuid
                                                                                 , arg1
                                                                                 , loadedVariableNameList_arg1
-                                                                                , VP_CLASS_STYLE_WIDTH_20PERCENT
+                                                                                , VP_CLASS_STYLE_WIDTH_35PERCENT
                                                                                 , STR_VARIABLE
                                                                                 , function(selectedValue) {
                                                                                     bindSelectValueEventFunc_while(selectedValue, 
@@ -361,7 +281,7 @@ define([
                         var sbIfArg2 = MakeVpSuggestInputText_apiblock(VP_ID_APIBLOCK_OPTION_WHILE_ARG_2 + index + uuid
                                             , arg2
                                             , WHILE_OPERATOR_ARG2
-                                            , VP_CLASS_STYLE_WIDTH_15PERCENT
+                                            , VP_CLASS_STYLE_WIDTH_25PERCENT
                                             , STR_OPERATOR
                                             , function(selectedValue) {
                                             bindSelectValueEventFunc_while(selectedValue, 
@@ -373,57 +293,37 @@ define([
                         var suggestInputArg3 =  MakeVpSuggestInputText_apiblock(VP_ID_APIBLOCK_OPTION_WHILE_ARG_3 + index + uuid
                                                                                 , arg3
                                                                                 , loadedVariableNameList_arg3
-                                                                                , VP_CLASS_STYLE_WIDTH_20PERCENT
+                                                                                , VP_CLASS_STYLE_WIDTH_35PERCENT
                                                                                 , STR_VARIABLE
                                                                                 , function(selectedValue) {
                                                                                     bindSelectValueEventFunc_while(selectedValue, 
                                                                                                                 index,
                                                                                                                 WHILE_BLOCK_SELECT_VALUE_ARG_TYPE.ARG3);
                                                                                     });   
-
-                        var sbIfArg4;
     
-                            sbIfArg4 =  MakeVpSuggestInputText_apiblock(VP_ID_APIBLOCK_OPTION_WHILE_ARG_4 + index + uuid
-                                , arg4
-                                , COMPARISON_OPERATOR_IF_ARG4
-                                , VP_CLASS_STYLE_WIDTH_15PERCENT
-                                , STR_OPERATOR
-                                , function(selectedValue) {
-                                    bindSelectValueEventFunc_while(selectedValue, 
-                                        index,
-                                        WHILE_BLOCK_SELECT_VALUE_ARG_TYPE.ARG4);
-                                });    
-         
-                        var suggestInputArg5 =  MakeVpSuggestInputText_apiblock(VP_ID_APIBLOCK_OPTION_WHILE_ARG_5 + index + uuid
-                                                                                , arg5
-                                                                                , loadedVariableNameList_arg5
-                                                                                , VP_CLASS_STYLE_WIDTH_20PERCENT
-                                                                                , STR_VARIABLE
-                                                                                , function(selectedValue) {
-                                                                                    bindSelectValueEventFunc_while(selectedValue, 
-                                                                                                                index,
-                                                                                                                WHILE_BLOCK_SELECT_VALUE_ARG_TYPE.ARG5);
-                                                                                    });    
-    
-                        var suggestInputArg6 =  MakeVpSuggestInputText_apiblock(VP_ID_APIBLOCK_OPTION_WHILE_ARG_6 + index + uuid
-                                                                                    , arg6
-                                                                                    , COMPARISON_OPERATOR_IF_ARG6
-                                                                                    , VP_CLASS_STYLE_WIDTH_10PERCENT
-                                                                                    , STR_OPERATOR
-                                                                                    , function(selectedValue) {
-                                                                                        bindSelectValueEventFunc_while(selectedValue, 
-                                                                                            index,
-                                                                                            WHILE_BLOCK_SELECT_VALUE_ARG_TYPE.ARG6);
-                                                                                });      
+                        // var suggestInputArg4 =  MakeVpSuggestInputText_apiblock(VP_ID_APIBLOCK_OPTION_WHILE_ARG_4 + index + uuid
+                        //                                                             , arg4
+                        //                                                             , COMPARISON_OPERATOR_IF_ARG4
+                        //                                                             , VP_CLASS_STYLE_WIDTH_15PERCENT
+                        //                                                             , STR_OPERATOR
+                        //                                                             , function(selectedValue) {
+                        //                                                                 bindSelectValueEventFunc_while(selectedValue, 
+                        //                                                                     index,
+                        //                                                                     WHILE_BLOCK_SELECT_VALUE_ARG_TYPE.ARG4);
+                        //                                                         });      
+                        var operArg4 = MakeOptionSelectBox(VP_ID_APIBLOCK_OPTION_WHILE_ARG_4 + index + uuid
+                                                    , VP_CLASS_STYLE_WIDTH_25PERCENT
+                                                    , arg4
+                                                    // , COMPARISON_OPERATOR_IF_ARG4);
+                                                    , ['and', 'or']);
                         sbConditionLeft.appendLine(suggestInputArg1);
                         sbConditionLeft.appendLine(sbIfArg2);
                         sbConditionLeft.appendLine(suggestInputArg3);
-                        sbConditionLeft.appendLine(sbIfArg4);
-                        sbConditionLeft.appendLine(suggestInputArg5);
                         sbConditionLeft.appendLine("</div>");
     
                         sbCondition.appendLine(sbConditionLeft.toString());
-                        sbCondition.appendLine(suggestInputArg6);
+                        // sbCondition.appendLine(suggestInputArg4);
+                        sbCondition.appendLine(operArg4);
     
                         var deleteConditionButton = MakeOptionDeleteButton(VP_ID_APIBLOCK_OPTION_WHILE_DELETE + index + uuid);
                         sbCondition.appendLine(deleteConditionButton);
@@ -464,32 +364,19 @@ define([
                      *  */
                     var ifConditionListState = thisBlock.getState(STATE_whileConditionList);   
                     ifConditionListState.forEach( (condition,index) => {
-                        const { arg1, arg2, arg3, arg4, arg5, arg6 } = condition;
+                        const { arg1, arg2, arg3, arg4 } = condition;
         
                         $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_1 + index + uuid).val(arg1);
                   
                         $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_3 + index + uuid).val(arg3);
-               
-                        $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_5 + index + uuid).val(arg5);
 
                         $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_2 + index + uuid).val(arg2);
-                        if (arg4 == '') {
-                            $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_4 + index + uuid).val(STR_EMPTY);
-                            $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_4 + index + uuid).addClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
-                            $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_5 + index + uuid).attr(STR_DISABLED, true);
-                            $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_5 + index + uuid).addClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
-                        } else {
-                            $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_4 + index + uuid).val(arg4);
-                            $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_4 + index + uuid).removeClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
-                            $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_5 + index + uuid).attr(STR_DISABLED, false);
-                            $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_5 + index + uuid).removeClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
-                        }     
       
                         if ( ifConditionListState.length -1 == index ) {
-                            $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_6 + index + uuid).addClass(VP_CLASS_STYLE_OPACITY_0);
+                            $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_4 + index + uuid).addClass(VP_CLASS_STYLE_OPACITY_0);
                         } else {
-                            $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_6 + index + uuid).val(arg6);
-                            $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_6 + index + uuid).addClass(VP_CLASS_STYLE_OPACITY_1);
+                            $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_4 + index + uuid).val(arg4);
+                            $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_4 + index + uuid).addClass(VP_CLASS_STYLE_OPACITY_1);
                         }
             
                     });
