@@ -213,6 +213,19 @@ define([
                     ${text}
                 </div>`);
     }
+    var renderUi = function(attribute) {
+        var { attributeStr, text } = parseAttributes(attribute);
+        return $(`<ul ${attributeStr}>
+                    ${text}
+                </div>`);
+    }
+
+    var renderLi = function(attribute) {
+        var { attributeStr, text } = parseAttributes(attribute);
+        return $(`<li ${attributeStr}>
+                    ${text}
+                </li>`);
+    }
 
     /**
      * @param {Object} option  
@@ -227,9 +240,9 @@ define([
     var renderCustomConfirmModal = function(option, confirmFunction, cancelFunction) {
         // load css
         vpCommon.loadCss( Jupyter.notebook.base_url + vpConst.BASE_PATH + vpConst.STYLE_PATH + "common/customConfirm.css" );
-        var title = `선택 하시겠습니까?`;
-        var confirm =  `예`;
-        var cancel = `아니오`;
+        var title = `Would you like to choose?`;
+        var confirm =  `Yes`;
+        var cancel = `No`;
 
         if(option) {
             var optionArray = Object.entries(option);
@@ -318,6 +331,8 @@ define([
         , renderSpan: renderSpan
         , renderLabel: renderLabel
         , renderDiv: renderDiv
+        , renderUi: renderUi
+        , renderLi: renderLi
         , renderCustomConfirmModal: renderCustomConfirmModal
     }
 });
\ No newline at end of file
