@@ -27,20 +27,22 @@ define([
         const { direction } = dirObj;
         if (direction === NAVIGATION_DIRECTION_TYPE.TO 
             || direction === NAVIGATION_DIRECTION_TYPE.PREV) {
-            const { destDir } = dirObj;
-            _executeCurrentPath(destDir, callback, fileNavigationRendererThis);
+            _executeCurrentPath(dirObj, callback, fileNavigationRendererThis);
         } else if (direction === NAVIGATION_DIRECTION_TYPE.TOP) {
-            _executeCurrentPath("..", callback, fileNavigationRendererThis);
+            dirObj.destDir = '..';
+            _executeCurrentPath(dirObj, callback, fileNavigationRendererThis);
         } else {
-            _executeCurrentPath(".", callback, fileNavigationRendererThis);
+            dirObj.destDir = '.';
+            _executeCurrentPath(dirObj, callback, fileNavigationRendererThis);
         }
     }
 
     /**
      * @private
      * 파이썬 커널로 현재 디렉토리의 폴더 및 파일 목록 가져오기 */ 
-    var _executeCurrentPath = function(path, callback, fileNavigationRendererThis) {
-        var currentPathStr = makeKernelCurrentPath(path);
+    var _executeCurrentPath = function(dirObj, callback, fileNavigationRendererThis) {
+        const { destDir, useFunction } = dirObj;
+        var currentPathStr = makeKernelCurrentPath(destDir, (useFunction? true : false));
         var fileNavigationState = fileNavigationRendererThis.getFileNavigationState();
         var dataOption = fileNavigationState.getFileOptionData();
         fileNavigationRendererThis.vpFuncJS.kernelExecute(currentPathStr, (result) => {
@@ -77,21 +79,62 @@ define([
                         return true;
                     }
 
-                    if (data.name && data.name.indexOf('vp') != -1
-                        || data.name && data.name.indexOf('txt') != -1
-                        || data.type && data.type.indexOf('dir') != -1) {
+                    if (data.type && data.type == 'dir') {
+                        // 폴더인 경우 표시
                         return true;
+                    } else if (data.name) {
+                        var extension = data.name.substring(data.name.lastIndexOf('.') + 1);
+                        var allowExtensionList = ['vp', 'txt'];
+                        if (allowExtensionList.includes(extension)) {
+                            return true;
+                        } else {
+                            return false;
+                        }
+                    } else {
+                        return false;
+                    }
+
+                    // if (data.name && data.name.indexOf('vp') != -1
+                    //     || data.name && data.name.indexOf('txt') != -1
+                    //     || data.type && data.type.indexOf('dir') != -1) {
+                    //     return true;
+                    // } else {
+                    //     return false;
+                    // }
+                });
+            }
+            /**
+             * 확장자가 여러 개 입력되었다면, 
+             * 해당 확장자 list에 포함된 확장자의 파일 목록 & 폴더 반환
+             */
+            if (Array.isArray(dataOption.fileExtension)) {
+                filterd_varList = filterd_varList.filter((data, index) => {
+                    if (index == 0) {
+                        return true;
+                    }
+
+                    if (data.type && data.type == 'dir') {
+                        // 폴더인 경우 표시
+                        return true;
+                    } else if (data.name) {
+                        var extension = data.name.substring(data.name.lastIndexOf('.') + 1);
+                        if (dataOption.fileExtension.includes(extension)) {
+                            return true;
+                        } else {
+                            return false;
+                        }
                     } else {
                         return false;
                     }
                 });
-
             }
 
             callback(filterd_varList);
         });
     }
 
+
+
     /**
      * @param {object} dirObj 
      * @param {fileNavigationRenderer This} fileNavigationRendererThis 
